@@ -22,8 +22,9 @@ from ..utils.py2 import lru_cache
 
 class DateSet(object):
     def __init__(self, f):
-        self._dates = bcolz.open(f, 'r')
-        self._index = self._dates.attrs['line_map']
+        dates = bcolz.open(f, 'r')
+        self._index = dates.attrs['line_map']
+        self._dates = [int(d) for d in dates]
 
     @lru_cache(None)
     def _get_set(self, s, e):
@@ -37,16 +38,19 @@ class DateSet(object):
 
         return self._get_set(s, e)
 
-    def contains(self, order_book_id, dt):
+    def contains(self, order_book_id, dates):
         try:
             s, e = self._index[order_book_id]
         except KeyError:
-            return False
+            return [False] * len(dates)
 
-        if isinstance(dt, (int, np.int64, np.uint64)):
-            if dt > 100000000:
-                dt //= 1000000
-        else:
-            dt = dt.year*10000 + dt.month*100 + dt.day
+        def _to_dt_int(d):
+            if isinstance(d, (int, np.int64, np.uint64)):
+                if d > 100000000:
+                    return int(d // 1000000)
+            else:
+                return d.year*10000 + d.month*100 + d.day
 
-        return dt in self._get_set(s, e)
+        date_set = self._get_set(s, e)
+
+        return [(_to_dt_int(d) in date_set) for d in dates]
