@@ -17,6 +17,12 @@
 import six
 
 
+if six.PY2:
+    import sys
+    reload(sys)
+    sys.setdefaultencoding("utf-8")
+
+
 def to_utf8(string):
     try:
         if six.PY2:
@@ -26,9 +32,21 @@ def to_utf8(string):
     except AttributeError:
         return to_utf8(str(string))
     except UnicodeDecodeError:
-        return unicode(string, 'utf-8')
+        return to_utf8(unicode(string, 'utf-8'))
+
+
+def from_utf8(string):
+    try:
+        return string.decode('utf-8')
+    except AttributeError:
+        return string
 
 try:
     from functools import lru_cache
 except ImportError:
     from fastcache import lru_cache
+
+try:
+    from inspect import signature
+except ImportError:
+    from funcsigs import signature
